<?php

namespace Drupal\monarch_bootstrap\Plugin\Alter\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\monarch_bootstrap\Plugin\Alter\AlterBase;

/**
 * Form alter plugin for the system_theme_settings form.
 *
 * @MonarchAlter("system_theme_settings")
 */
class SystemThemeSettingsAlter extends AlterBase {

  /**
   * {@inheritdoc}
   */
  public function alter(&$data, &$context1 = NULL, &$context2 = NULL) {
    $form = &$data;
    $form_state = $context1;
    $form_id = $context2;

    $theme_name = $this->getActiveTheme()->getName();
    
    $form['bootstrap'] = [
      '#type' => 'vertical_tabs',
      '#prefix' => '<h2><small>' . t('Bootstrap Settings') . '</small></h2>',
      '#weight' => -10,
    ];
    $groups = [
      'regions' => t('Regions'),
      'components' => t('Components'),
    ];
    foreach ($groups as $group => $title) {
      $form[$group] = [
        '#type' => 'details',
        '#title' => $title,
        '#group' => 'bootstrap',
      ];
    }

    // Region settings
    $regions = system_region_list($this->getActiveTheme()->getExtension());
    foreach ($regions as $region_key => $region) {
      $form['regions'][$region_key] = [
        '#type' => 'details',
        '#title' => $region,
        '#tree' => TRUE,
      ];

      $form['regions'][$region_key]['container'] = [
        '#type' => 'select',
        '#title' => $this->t('@region container', ['@region' => $region]),
        '#options' => [
          'none' => $this->t('None'),
          'container' => $this->t('Default'),
          'container-fluid' => $this->t('Fluid'),
          'container-sm' => $this->t('Small'),
          'container-md' => $this->t('Medium'),
          'container-lg' => $this->t('Large'),
          'container-xl' => $this->t('X-Large'),
          'container-xxl' => $this->t('XX-Large'),
        ],
        '#default_value' => theme_get_setting($region_key . '.container', $theme_name),
        '#description' => $this->t('Select the type of container to use for this region. See <a href=":url">https://getbootstrap.com/docs/5.1/layout/containers</a>', [':url' => 'https://getbootstrap.com/docs/5.1/layout/containers']),
      ];

      $form['regions'][$region_key]['bg_color'] = [
        '#type' => 'select',
        '#title' => $this->t('@region background color', ['@region' => $region]),
        '#options' => [
          'none' => $this->t('None'),
          'bg-transparent' => $this->t('Transparent'),
          'bg-white' => $this->t('White'),
          'bg-light' => $this->t('Light'),
          'bg-dark' => $this->t('Dark'),
          'bg-primary' => $this->t('Primary'),
          'bg-secondary' => $this->t('Secondary'),
          'bg-success' => $this->t('Success'),
          'bg-info' => $this->t('Info'),
          'bg-warning' => $this->t('Warning'),
          'bg-danger' => $this->t('Danger'),
        ],
        '#default_value' => theme_get_setting($region_key . '.bg_color', $theme_name),
        '#description' => $this->t('Select the background color for this region. Colors are definied in variables.scss. Use "None" to exclude bootstrap background classes and allow customization in scss. See <a href=":url">https://getbootstrap.com/docs/5.1/customize/color/</a>', [':url' => 'https://getbootstrap.com/docs/5.1/customize/color/']),
      ];
    }
    
  }

}
