<?php

namespace Drupal\monarch_bootstrap\Plugin\Preprocess;

use Drupal\Core\Plugin\PluginBase;
use Drupal\Core\Theme\ThemeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base class for template preprocess plugins.
 */
abstract class PreprocessBase extends PluginBase 
  implements PreprocessInterface, ContainerFactoryPluginInterface {

  /**
   * The theme preprocess hook invoked.
   *
   * @var string
   */
  protected $hook;

  /**
   * The theme preprocess hook info array from the theme registry.
   *
   * @var mixed[]
   */
  protected $info;

  /**
   * The theme manager service.
   * 
   * @var \Drupal\Core\Theme\ThemeManagerInterface
   */
  protected $themeManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('theme.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function __construct(
    array $configuration, $plugin_id, $plugin_definition,
    ThemeManagerInterface $theme_manager) {

    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->themeManager = $theme_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function preprocess(array &$variables, $hook, array $info) {
    $this->hook = $hook;
    $this->info = $info;

    // These variables are useful to all templates.
    $variables['path_to_theme'] = $this->getActiveTheme()->getPath();
    $variables['theme_name'] = $this->getActiveTheme()->getName();
  }

  /**
   * Get the active theme object.
   * 
   * @return \Drupal\Core\Theme\ActiveTheme
   */
  public function getActiveTheme() {
    return $this->themeManager->getActiveTheme();
  }

}
